@@ -16,13 +16,17 @@ import json
 import re
 
 
-def test_push_file(archive, random_metadata, tmpfile, s3_key):
+def _get_contents_as_string(obj):
+    return obj.get()['Body'].read()
+
+
+def test_push_file(archive, random_metadata, tmpfile, s3_object):
     expected_content = 'mwahaha'.encode('utf-8')
     f = tmpfile(expected_content)
     url = archive.prepare_metadata_and_push(f, **random_metadata)
-    from_s3 = s3_key(url)
-    assert from_s3.get_contents_as_string() == expected_content
-    metadata = from_s3.get_metadata('datalake')
+    from_s3 = s3_object(url)
+    assert _get_contents_as_string(from_s3) == expected_content
+    metadata = from_s3.get()['Metadata'].get('datalake')
     assert metadata is not None
     metadata = json.loads(metadata)
     common_keys = set(metadata.keys()).intersection(random_metadata.keys())
@@ -30,14 +34,14 @@ def test_push_file(archive, random_metadata, tmpfile, s3_key):
 
 
 def test_push_large_file(
-        monkeypatch, archive, random_metadata, tmpfile, s3_key):
-    monkeypatch.setenv('DATALAKE_CHUNK_SIZE_MB', 5)
+        monkeypatch, archive, random_metadata, tmpfile, s3_object):
+    monkeypatch.setenv('DATALAKE_CHUNK_SIZE_MB', '5')
     expected_content = ('big data' * 1024 * 1024).encode('utf-8')
     f = tmpfile(expected_content)
     url = archive.prepare_metadata_and_push(f, **random_metadata)
-    from_s3 = s3_key(url)
-    assert from_s3.get_contents_as_string() == expected_content
-    metadata = from_s3.get_metadata('datalake')
+    from_s3 = s3_object(url)
+    assert _get_contents_as_string(from_s3) == expected_content
+    metadata = from_s3.get()['Metadata'].get('datalake')
     assert metadata is not None
     metadata = json.loads(metadata)
     common_keys = set(metadata.keys()).intersection(random_metadata.keys())
